@@ -38,6 +38,7 @@
 #include <QTimer>
 #include <QApplication>
 #include <QDateTime>
+#include <QDesktopWidget>
 
 #ifdef Q_WS_MAEMO_5
 #include <QMaemo5InformationBox>
@@ -66,6 +67,10 @@ GameView::GameView(QWidget *parent) :
 
     if(QFile::exists(QString("%1/%2/%3")
                     .arg(QDir::homePath()).arg(HOME_DIRECTORY).arg(RESTORE_FILE))) {
+        QDesktopWidget dw;
+        QRect rect = dw.availableGeometry();
+        Settings::setImageWidth(rect.width() * 0.8);
+        Settings::setImageHeight(rect.height() * 0.8);
         if(!restoreGame()) {
             setPieces(ImageImporter::instance()->newPieces(Settings::instance()->image(), Settings::instance()->pieceCount()));
             PuzzleItem::setMoveCount(0);
@@ -127,8 +132,8 @@ void GameView::setPieces(const QList<PuzzleItem *> pieces, bool shuffle)
     }
 
     int verticalCount = pieces_.count() / horizontalCount;
-    horizontalStep_ = IMAGE_WIDTH / horizontalCount + 5;
-    verticalStep_ = IMAGE_HEIGHT / verticalCount + 5;
+    horizontalStep_ = Settings::imageWidth() / horizontalCount + 5;
+    verticalStep_ = Settings::imageHeight() / verticalCount + 5;
 
     int pieceNumber = 0;
 
